# smart-insights

smart-insights is a part of [Dash Enterprise](https://plotly.com/dash/),
Plotly's end-to-end Dash application platform. This public copy of the package
is a stub published on pypi.org designed to shield Dash Enterprise users from
[dependency confusion](https://medium.com/@alex.birsan/dependency-confusion-4a5d60fec610),
a remote code execution attack publicly disclosed in 2021 by Alex Birsan.

If you are a Dash Enterprise user, you will only see this public package if your
app is not properly configured to find the local package repository built into
Dash Enterprise. Visit the docs for your Dash Enterprise installation for details.

If you never see this public package, it's still doing its job of protecting you
from the dependency confusion attack!
